==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2a439cf17984355c3393b871ffc46d02.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Service/SearchCommandList.php */
class __TwigTemplate_db183d795d0872aee5d36ce8ffac16ee extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Service;

use Mautic\\CoreBundle\\CoreEvents;
use Mautic\\CoreBundle\\Event\\CommandListEvent;
use Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface;

final class SearchCommandList implements SearchCommandListInterface
{
    /**
     * @var mixed[]
     */
    private array \$searchCommands = [];

    public function __construct(
        private EventDispatcherInterface \$dispatcher
    ) {
    }

    public function getList(): array
    {
        if (!empty(\$this->searchCommands)) {
            return \$this->searchCommands;
        }

        \$event = new CommandListEvent();
        \$this->dispatcher->dispatch(\$event, CoreEvents::BUILD_COMMAND_LIST);

        return \$this->searchCommands = \$event->getCommands();
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Service/SearchCommandList.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Service/SearchCommandList.php", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Service/SearchCommandList.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/2a/2a439cf17984355c3393b871ffc46d02.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Service/SearchCommandList.php */
class __TwigTemplate_db183d795d0872aee5d36ce8ffac16ee extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\CoreBundle\\Service;

use Mautic\\CoreBundle\\CoreEvents;
use Mautic\\CoreBundle\\Event\\CommandListEvent;
use Symfony\\Contracts\\EventDispatcher\\EventDispatcherInterface;

final class SearchCommandList implements SearchCommandListInterface
{
    /**
     * @var mixed[]
     */
    private array \$searchCommands = [];

    public function __construct(
        private EventDispatcherInterface \$dispatcher
    ) {
    }

    public function getList(): array
    {
        if (!empty(\$this->searchCommands)) {
            return \$this->searchCommands;
        }

        \$event = new CommandListEvent();
        \$this->dispatcher->dispatch(\$event, CoreEvents::BUILD_COMMAND_LIST);

        return \$this->searchCommands = \$event->getCommands();
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Service/SearchCommandList.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Service/SearchCommandList.php", "/var/www/html/production-demo/app/bundles/CoreBundle/Service/SearchCommandList.php");
    }
}
